# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ReportProblemWithTripRetrieveParams"]


class ReportProblemWithTripRetrieveParams(TypedDict, total=False):
    code: Literal[
        "vehicle_never_came",
        "vehicle_came_early",
        "vehicle_came_late",
        "wrong_headsign",
        "vehicle_does_not_stop_here",
        "other",
    ]
    """A string code identifying the nature of the problem"""

    service_date: Annotated[int, PropertyInfo(alias="serviceDate")]
    """The service date of the trip"""

    stop_id: Annotated[str, PropertyInfo(alias="stopID")]
    """A stop ID indicating where the user is experiencing the problem"""

    user_comment: Annotated[str, PropertyInfo(alias="userComment")]
    """Additional comment text supplied by the user describing the problem"""

    user_lat: Annotated[float, PropertyInfo(alias="userLat")]
    """The reporting user’s current latitude"""

    user_location_accuracy: Annotated[float, PropertyInfo(alias="userLocationAccuracy")]
    """The reporting user’s location accuracy, in meters"""

    user_lon: Annotated[float, PropertyInfo(alias="userLon")]
    """The reporting user’s current longitude"""

    user_on_vehicle: Annotated[bool, PropertyInfo(alias="userOnVehicle")]
    """Indicator if the user is on the transit vehicle experiencing the problem"""

    user_vehicle_number: Annotated[str, PropertyInfo(alias="userVehicleNumber")]
    """The vehicle number, as reported by the user"""

    vehicle_id: Annotated[str, PropertyInfo(alias="vehicleID")]
    """The vehicle actively serving the trip"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .._types import Body, Query, Headers, NotGiven, not_given
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.routes_for_agency_list_response import RoutesForAgencyListResponse

__all__ = ["RoutesForAgencyResource", "AsyncRoutesForAgencyResource"]


class RoutesForAgencyResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> RoutesForAgencyResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return RoutesForAgencyResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RoutesForAgencyResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return RoutesForAgencyResourceWithStreamingResponse(self)

    def list(
        self,
        agency_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RoutesForAgencyListResponse:
        """
        Retrieve the list of all routes for a particular agency by id

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not agency_id:
            raise ValueError(f"Expected a non-empty value for `agency_id` but received {agency_id!r}")
        return self._get(
            f"/api/where/routes-for-agency/{agency_id}.json",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RoutesForAgencyListResponse,
        )


class AsyncRoutesForAgencyResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncRoutesForAgencyResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncRoutesForAgencyResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRoutesForAgencyResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return AsyncRoutesForAgencyResourceWithStreamingResponse(self)

    async def list(
        self,
        agency_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RoutesForAgencyListResponse:
        """
        Retrieve the list of all routes for a particular agency by id

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not agency_id:
            raise ValueError(f"Expected a non-empty value for `agency_id` but received {agency_id!r}")
        return await self._get(
            f"/api/where/routes-for-agency/{agency_id}.json",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RoutesForAgencyListResponse,
        )


class RoutesForAgencyResourceWithRawResponse:
    def __init__(self, routes_for_agency: RoutesForAgencyResource) -> None:
        self._routes_for_agency = routes_for_agency

        self.list = to_raw_response_wrapper(
            routes_for_agency.list,
        )


class AsyncRoutesForAgencyResourceWithRawResponse:
    def __init__(self, routes_for_agency: AsyncRoutesForAgencyResource) -> None:
        self._routes_for_agency = routes_for_agency

        self.list = async_to_raw_response_wrapper(
            routes_for_agency.list,
        )


class RoutesForAgencyResourceWithStreamingResponse:
    def __init__(self, routes_for_agency: RoutesForAgencyResource) -> None:
        self._routes_for_agency = routes_for_agency

        self.list = to_streamed_response_wrapper(
            routes_for_agency.list,
        )


class AsyncRoutesForAgencyResourceWithStreamingResponse:
    def __init__(self, routes_for_agency: AsyncRoutesForAgencyResource) -> None:
        self._routes_for_agency = routes_for_agency

        self.list = async_to_streamed_response_wrapper(
            routes_for_agency.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["TripDetailRetrieveParams"]


class TripDetailRetrieveParams(TypedDict, total=False):
    include_schedule: Annotated[bool, PropertyInfo(alias="includeSchedule")]
    """
    Whether to include the full schedule element in the tripDetails section
    (defaults to true).
    """

    include_status: Annotated[bool, PropertyInfo(alias="includeStatus")]
    """
    Whether to include the full status element in the tripDetails section (defaults
    to true).
    """

    include_trip: Annotated[bool, PropertyInfo(alias="includeTrip")]
    """
    Whether to include the full trip element in the references section (defaults to
    true).
    """

    service_date: Annotated[int, PropertyInfo(alias="serviceDate")]
    """Service date for the trip as Unix time in milliseconds (optional)."""

    time: int
    """Time parameter to query the system at a specific time (optional)."""



import onebusaway


def main_sync() -> None:
    client = onebusaway.OnebusawaySDK(api_key="TEST")
    stop_id = "1_75403"
    schedule_for_stop = client.schedule_for_stop.retrieve(stop_id)

    if schedule_for_stop.data and schedule_for_stop.data.entry:
        print(schedule_for_stop.data.entry)
    else:
        print("schedule data or entry is None.")


if __name__ == "__main__":
    main_sync()



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = ["ShapeRetrieveResponse", "ShapeRetrieveResponseData", "ShapeRetrieveResponseDataEntry"]


class ShapeRetrieveResponseDataEntry(BaseModel):
    length: int

    points: str
    """Encoded polyline format representing the shape of the path"""

    levels: Optional[str] = None


class ShapeRetrieveResponseData(BaseModel):
    entry: ShapeRetrieveResponseDataEntry

    references: References


class ShapeRetrieveResponse(ResponseWrapper):
    data: ShapeRetrieveResponseData



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = ["TripRetrieveResponse", "TripRetrieveResponseData", "TripRetrieveResponseDataEntry"]


class TripRetrieveResponseDataEntry(BaseModel):
    id: str

    route_id: str = FieldInfo(alias="routeId")

    service_id: str = FieldInfo(alias="serviceId")

    block_id: Optional[str] = FieldInfo(alias="blockId", default=None)

    direction_id: Optional[str] = FieldInfo(alias="directionId", default=None)

    peak_offpeak: Optional[int] = FieldInfo(alias="peakOffpeak", default=None)

    route_short_name: Optional[str] = FieldInfo(alias="routeShortName", default=None)

    shape_id: Optional[str] = FieldInfo(alias="shapeId", default=None)

    time_zone: Optional[str] = FieldInfo(alias="timeZone", default=None)

    trip_headsign: Optional[str] = FieldInfo(alias="tripHeadsign", default=None)

    trip_short_name: Optional[str] = FieldInfo(alias="tripShortName", default=None)


class TripRetrieveResponseData(BaseModel):
    entry: TripRetrieveResponseDataEntry

    references: References


class TripRetrieveResponse(ResponseWrapper):
    data: TripRetrieveResponseData
